@@ -1,7 +1,8 @@
 from io import BytesIO
 
-from buidl.bech32 import encode_bech32_checksum
+from buidl.bech32 import decode_bech32, encode_bech32_checksum
 from buidl.helper import (
+    decode_base58,
     encode_base58_checksum,
     encode_varstr,
     hash160,
@@ -12,6 +13,8 @@ from buidl.helper import (
     sha256,
 )
 from buidl.op import (
+    number_to_op_code,
+    op_code_to_number,
     op_equal,
     op_hash160,
     op_verify,
@@ -318,11 +321,11 @@ class P2PKHScriptPubKey(ScriptPubKey):
     def hash160(self):
         return self.commands[2]
 
-    def address(self, testnet=False):
-        if testnet:
-            prefix = b"\x6f"
-        else:
+    def address(self, network="mainnet"):
+        if network == "mainnet":
             prefix = b"\x00"
+        else:
+            prefix = b"\x6f"
         # return the encode_base58_checksum the prefix and h160
         return encode_base58_checksum(prefix + self.hash160())
 
@@ -337,11 +340,11 @@ class P2SHScriptPubKey(ScriptPubKey):
     def hash160(self):
         return self.commands[1]
 
-    def address(self, testnet=False):
-        if testnet:
-            prefix = b"\xc4"
-        else:
+    def address(self, network="mainnet"):
+        if network == "mainnet":
             prefix = b"\x05"
+        else:
+            prefix = b"\xc4"
         # return the encode_base58_checksum the prefix and h160
         return encode_base58_checksum(prefix + self.hash160())
 
@@ -349,6 +352,9 @@ class P2SHScriptPubKey(ScriptPubKey):
 class RedeemScript(Script):
     """Subclass that represents a RedeemScript for p2sh"""
 
+    def is_p2sh_multisig(self):
+        return self.commands[-1] == 174
+
     def hash160(self):
         """Returns the hash160 of the serialization of the RedeemScript"""
         return hash160(self.raw_serialize())
@@ -357,27 +363,92 @@ class RedeemScript(Script):
         """Returns the ScriptPubKey that this RedeemScript corresponds to"""
         return P2SHScriptPubKey(self.hash160())
 
-    def address(self, testnet=False):
+    def address(self, network="mainnet"):
         """Returns the p2sh address for this RedeemScript"""
-        return self.script_pubkey().address(testnet)
+        return self.script_pubkey().address(network)
 
     @classmethod
     def convert(cls, raw_redeem_script):
         stream = BytesIO(encode_varstr(raw_redeem_script))
         return cls.parse(stream)
 
+    @classmethod
+    def create_p2sh_multisig(
+        cls,
+        quorum_m,
+        pubkey_hexes,
+        sort_keys=True,
+        expected_addr=None,
+        expected_addr_network="mainnet",
+    ):
+        """
+        Create a p2sh RedeemScript using a configure threshold (quorum_m) of child public keys (in hex).
+
+        To use a custom order of pubkeys, feed them in order and set sort_keys=False
+
+        For safety, you may pass in an expected_addr and the method will throw an error if the derived address doesn't match the expected one.
+        """
+        # safety checks
+        if type(quorum_m) is not int:
+            raise ValueError(f"quorum_m must be of type int: {quorum_m}")
+        if quorum_m < 1 or quorum_m > len(pubkey_hexes):
+            raise ValueError(f"Invalid m-of-n: {quorum_m}-of-{len(pubkey_hexes)}")
+
+        commands = [number_to_op_code(quorum_m)]
+
+        if sort_keys:
+            pubkey_hexes = sorted(pubkey_hexes)
+
+        for pubkey_hex in pubkey_hexes:
+            # we want these in binary (not hex)
+            commands.append(bytes.fromhex(pubkey_hex))
+
+        quorum_n = len(pubkey_hexes)
+        commands.append(number_to_op_code(quorum_n))
+        commands.append(174)  # OP_CHECKMULTISIG
+
+        to_return = cls(commands)
+
+        if expected_addr:
+            calculated_addr = to_return.address(network=expected_addr_network)
+            if expected_addr != calculated_addr:
+                raise ValueError(
+                    f"Expected address {expected_addr} but calculated {calculated_addr}"
+                )
+
+        return to_return
+
+    def get_quorum(self):
+        """
+        Return the m-of-n of this multisig, as in 2-of-3 or 3-of-5
+        """
+        if not self.is_p2sh_multisig():
+            raise ValueError(f"Not p2sh multisig: {self}")
+        quorum_m = op_code_to_number(self.commands[0])
+        # 3 because quorum_m, OP_CHECKMULTISIG, and bitcoin off-by-one error
+        quorum_n = len(self.commands) - 3
+        return quorum_m, quorum_n
+
+    def signing_pubkeys(self):
+        """
+        The pubkeys needed to sign this transaction, typically children derived from xpubs
+        """
+        if not self.is_p2sh_multisig():
+            raise ValueError(f"Not p2sh multisig: {self}")
+        return self.commands[1:-2]
+
 
 class SegwitPubKey(ScriptPubKey):
-    def address(self, testnet=False):
+    def address(self, network="mainnet"):
         """return the bech32 address for the p2wpkh"""
         # witness program is the raw serialization
         witness_program = self.raw_serialize()
         # convert to bech32 address using encode_bech32_checksum
-        return encode_bech32_checksum(witness_program, testnet)
+        return encode_bech32_checksum(witness_program, network)
 
-    def p2sh_address(self, testnet=False):
+    def p2sh_address(self, network="mainnet"):
         # get the RedeemScript equivalent and get its address
-        return self.redeem_script().address(testnet)
+        return self.redeem_script().address(network)
 
 
 class P2WPKHScriptPubKey(SegwitPubKey):
@@ -415,19 +486,19 @@ class WitnessScript(Script):
         # return new p2wsh script using p2wsh_script
         return P2WSHScriptPubKey(s256)
 
-    def address(self, testnet=False):
+    def address(self, network="mainnet"):
         """Generates a p2wsh address"""
         # grab the entire witness program
         witness_program = self.script_pubkey().raw_serialize()
         # convert to bech32 address using encode_bech32_checksum
-        return encode_bech32_checksum(witness_program, testnet)
+        return encode_bech32_checksum(witness_program, network)
 
-    def p2sh_address(self, testnet=False):
+    def p2sh_address(self, network="mainnet"):
         """Generates a p2sh-p2wsh address"""
         # the RedeemScript is the p2wsh ScriptPubKey
         redeem_script = self.script_pubkey().redeem_script()
-        # return the p2sh address of the RedeemScript (remember testnet)
-        return redeem_script.address(testnet)
+        # return the p2sh address of the RedeemScript (remember network)
+        return redeem_script.address(network)
 
     def is_p2wsh_multisig(self):
         return (
@@ -448,3 +519,23 @@ class WitnessScript(Script):
         quorum_n = OP_CODE_NAMES[self.commands[-2]].split("OP_")[1]
 
         return int(quorum_m), int(quorum_n)
+
+
+def address_to_script_pubkey(s):
+    if s[:1] in ("1", "m", "n"):
+        # p2pkh
+        h160 = decode_base58(s)
+        return P2PKHScriptPubKey(h160)
+    elif s[:1] in ("2", "3"):
+        # p2sh
+        h160 = decode_base58(s)
+        return P2SHScriptPubKey(h160)
+    elif s[:3] in ("bc1", "tb1"):
+        if len(s) == 42:
+            # p2wpkh
+            return P2WPKHScriptPubKey(decode_bech32(s)[2])
+        elif len(s) == 62:
+            # p2wskh
+            return P2WSHScriptPubKey(decode_bech32(s)[2])
+
+    raise RuntimeError("unknown type of address: {}".format(s))
